==> jc-1.4.0.tar.gz: javax/naming/LinkRef.h <==
// public class javax.naming.LinkRef

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 25a406da8bdbb541 javax_naming_LinkRef
// @dep_class 6d5b74cd2a0dd28c javax_naming_Reference

// header file dependencies
// @dep_header javax_naming_Reference

#include "javax/naming/Reference.h"

#ifndef _JC_javax_naming_LinkRef_H_
#define _JC_javax_naming_LinkRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_naming_Name$object;

// Typedefs
typedef struct _jc_javax_naming_LinkRef$sub_refs	_jc_javax_naming_LinkRef$sub_refs;
typedef struct _jc_javax_naming_LinkRef$sub_nonrefs	_jc_javax_naming_LinkRef$sub_nonrefs;
typedef struct _jc_javax_naming_LinkRef$refs	_jc_javax_naming_LinkRef$refs;
typedef struct _jc_javax_naming_LinkRef$nonrefs	_jc_javax_naming_LinkRef$nonrefs;
typedef struct _jc_javax_naming_LinkRef$object	_jc_javax_naming_LinkRef$object;

typedef struct _jc_javax_naming_LinkRef$fields_struct	_jc_javax_naming_LinkRef$fields_struct;
typedef const struct _jc_javax_naming_LinkRef$vmethods	_jc_javax_naming_LinkRef$vmethods;
typedef const struct _jc_javax_naming_LinkRef$vtable	_jc_javax_naming_LinkRef$vtable;
typedef const struct _jc_javax_naming_LinkRef$vtype	_jc_javax_naming_LinkRef$vtype;

// Class fields structure
struct _jc_javax_naming_LinkRef$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_naming_LinkRef$fields_struct _jc_javax_naming_LinkRef$class_fields;

// Constructors
extern void _jc_javax_naming_LinkRef$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_LinkRef$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_naming_LinkRef$method$_init$2bbe29b51c773d0a(_jc_env *, struct _jc_javax_naming_LinkRef$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_naming_LinkRef$method$getLinkName$7a7339e8eb84dcc1(_jc_env *, struct _jc_javax_naming_LinkRef$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_LinkRef$method_info$getLinkName$7a7339e8eb84dcc1;

// Virtual methods structure
struct _jc_javax_naming_LinkRef$vmethods {
	struct _jc_java_lang_String$object	*(*getLinkName$7a7339e8eb84dcc1)(_jc_env *, struct _jc_javax_naming_LinkRef$object *);
};

// Vtable
struct _jc_javax_naming_LinkRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_Reference$vmethods	javax_naming_Reference;
	_jc_javax_naming_LinkRef$vmethods	javax_naming_LinkRef;
};

// Vtype
struct _jc_javax_naming_LinkRef$vtype {
	_jc_type			type;
	_jc_javax_naming_LinkRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_LinkRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_LinkRef$refs {
    _jc_javax_naming_LinkRef$sub_refs	javax_naming_LinkRef;
    _jc_javax_naming_Reference$sub_refs	javax_naming_Reference;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_LinkRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_LinkRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_Reference$sub_nonrefs	javax_naming_Reference;
    _jc_javax_naming_LinkRef$sub_nonrefs	javax_naming_LinkRef;
};

// Object instance structure
struct _jc_javax_naming_LinkRef$object {
	_jc_javax_naming_LinkRef$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_LinkRef$vtype	*vtype;
	_jc_javax_naming_LinkRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_LinkRef$vtype _jc_javax_naming_LinkRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_LinkRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_LinkRef$class_object;

#endif	/* _JC_javax_naming_LinkRef_H_ */

==> jc-1.4.6.tar.gz: javax/naming/LinkRef.h <==
// public class javax.naming.LinkRef

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 25a406da8bdbb541 javax_naming_LinkRef
// @dep_class 6d5b74cd2a0dd28c javax_naming_Reference

// header file dependencies
// @dep_header javax_naming_Reference

#include "javax/naming/Reference.h"

#ifndef _JC_javax_naming_LinkRef_H_
#define _JC_javax_naming_LinkRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_naming_Name$object;

// Typedefs
typedef struct _jc_javax_naming_LinkRef$sub_refs	_jc_javax_naming_LinkRef$sub_refs;
typedef struct _jc_javax_naming_LinkRef$sub_nonrefs	_jc_javax_naming_LinkRef$sub_nonrefs;
typedef struct _jc_javax_naming_LinkRef$refs	_jc_javax_naming_LinkRef$refs;
typedef struct _jc_javax_naming_LinkRef$nonrefs	_jc_javax_naming_LinkRef$nonrefs;
typedef struct _jc_javax_naming_LinkRef$object	_jc_javax_naming_LinkRef$object;

typedef struct _jc_javax_naming_LinkRef$fields_struct	_jc_javax_naming_LinkRef$fields_struct;
typedef const struct _jc_javax_naming_LinkRef$vmethods	_jc_javax_naming_LinkRef$vmethods;
typedef const struct _jc_javax_naming_LinkRef$vtable	_jc_javax_naming_LinkRef$vtable;
typedef const struct _jc_javax_naming_LinkRef$vtype	_jc_javax_naming_LinkRef$vtype;

// Class fields structure
struct _jc_javax_naming_LinkRef$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_naming_LinkRef$fields_struct _jc_javax_naming_LinkRef$class_fields;

// Constructors
extern void _jc_javax_naming_LinkRef$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_LinkRef$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_LinkRef$method$_init$2bbe29b51c773d0a(_jc_env *, struct _jc_javax_naming_LinkRef$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_naming_LinkRef$method$getLinkName$7a7339e8eb84dcc1(_jc_env *, struct _jc_javax_naming_LinkRef$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_LinkRef$method_info$getLinkName$7a7339e8eb84dcc1;

// Virtual methods structure
struct _jc_javax_naming_LinkRef$vmethods {
	struct _jc_java_lang_String$object	*(*getLinkName$7a7339e8eb84dcc1)(_jc_env *, struct _jc_javax_naming_LinkRef$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_LinkRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_Reference$vmethods	javax_naming_Reference;
	_jc_javax_naming_LinkRef$vmethods	javax_naming_LinkRef;
};

// Vtype
struct _jc_javax_naming_LinkRef$vtype {
	_jc_type			type;
	_jc_javax_naming_LinkRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_LinkRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_LinkRef$refs {
    _jc_javax_naming_LinkRef$sub_refs	javax_naming_LinkRef;
    _jc_javax_naming_Reference$sub_refs	javax_naming_Reference;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_LinkRef$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_LinkRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_Reference$sub_nonrefs	javax_naming_Reference;
    _jc_javax_naming_LinkRef$sub_nonrefs	javax_naming_LinkRef;
};

// Object instance structure
struct _jc_javax_naming_LinkRef$object {
	_jc_javax_naming_LinkRef$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_LinkRef$vtype	*vtype;
	_jc_javax_naming_LinkRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_LinkRef$vtype _jc_javax_naming_LinkRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_LinkRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_LinkRef$class_object;

#endif	/* _JC_javax_naming_LinkRef_H_ */
